@@ -3,4 +3,4 @@ import os
 ROOT_DIR = os.path.dirname(os.path.abspath(__file__))
 
 
-AUDIO_FILE_PATH = f'{ROOT_DIR}/audio/'
+AUDIO_FILE_PATH = f"{ROOT_DIR}/audio/"
